from flask import Flask, request, redirect, g
from flask_babel import Babel
from peewee import MySQLDatabase, OperationalError
from config import DATABASE

app = Flask(__name__)
app.config.from_object('config')
babel = Babel(app)

db = MySQLDatabase(DATABASE['name'], host=DATABASE['host'],
                   user=DATABASE['user'], password=DATABASE['passwd'])

# This hook ensures that a connection is opened to handle any queries
# generated by the request.
@app.before_request
def _db_connect():
    try:
        db.connect()
    except OperationalError as e:
        return e


# This hook ensures that the connection is closed when we've finished
# processing the request.
@app.teardown_request
def _db_close(exc):
    if not db.is_closed():
        db.close()


@app.before_request
def set_language():
    try:
        lang = request.view_args['lang']

        if lang in app.config['LANGUAGES']:
            language = lang
        else:
            # Requested language is not a valid one !
            return redirect('/')
    except:
        language = request.accept_languages.best_match(
            app.config['LANGUAGES'].keys())

    # No languages match! Fallback to Configuration settings 'Default Language'
    if not language:
        language = app.config['DEFAULT_LANGUAGE']

    g.locale = language


@babel.localeselector
def get_locale():

    return g.locale


from . import views, models

app.register_blueprint(views.groups, url_prefix='/groups')
app.register_blueprint(views.hosts, url_prefix='/hosts')
